@@ -6,7 +6,7 @@ use Test::Builder;
 use Sub::Uplevel qw( uplevel );
 use base qw( Exporter );
 
-our $VERSION = '0.30_1';
+our $VERSION = '0.30_2';
 our @EXPORT = qw(dies_ok lives_ok throws_ok lives_and);
 
 my $Tester = Test::Builder->new;
@@ -198,6 +198,11 @@ A true value is returned if the test succeeds, false otherwise. On exit $@ is gu
 
 A description of the exception being checked is used if no optional test description is passed.
 
+NOTE: Rememeber when you C<die $string_without_a_trailing_newline> perl will 
+automatically add the current script line number, input line number and a newline. This will
+form part of the string that throws_ok regular expressions match against.
+
+
 =cut
 
 
@@ -427,7 +432,9 @@ chromatic,
 Curt Sampson,
 David Cantrell,
 David Golden, 
+David Tulloh,
 David Wheeler, 
+J. K. O'Brien,
 Janek Schleicher,
 Jim Keenan, 
 Jos I. Boumans, 
@@ -438,16 +445,16 @@ Michael G Schwern,
 Nadim Khemir,
 Paul McCann,
 Perrin Harkins, 
+Peter Rabbitson,
 Peter Scott, 
 Ricardo Signes,
-Rob Muhlestein 
+Rob Muhlestein,
 Scott R. Godin,
 Steve Purkis,
 Steve, 
 Tim Bunce,
 and various anonymous folk for comments, suggestions, bug reports and patches.
 
-
 =head1 AUTHOR
 
 Adrian Howard <adrianh@quietstars.com>
